package com.example.ogata.calltaxi;

import android.app.Fragment;
import android.content.Context;
import android.content.SharedPreferences;
import android.os.AsyncTask;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.TextView;

import com.google.android.gms.common.ConnectionResult;
import com.google.android.gms.common.api.GoogleApiClient;
import com.google.android.gms.common.api.PendingResult;
import com.google.android.gms.wearable.MessageApi;
import com.google.android.gms.wearable.Node;
import com.google.android.gms.wearable.NodeApi;
import com.google.android.gms.wearable.PutDataMapRequest;
import com.google.android.gms.wearable.Wearable;

import java.util.Collection;
import java.util.concurrent.TimeUnit;

import static com.example.ogata.calltaxi.MyActivity.TAG;

public class CallFragment extends Fragment implements Runnable {
    private GoogleApiClient mClient;
    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
            Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.fragment_call, container, false);
        Button button = (Button) view.findViewById(R.id.btn);
        button.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                call();
            }
        });
        String number = getPhoneNumber();
        TextView textView = (TextView) view.findViewById(R.id.number);
        textView.setText(number);

        mClient = initClient();
        mClient.connect();
        return view;
    }

    @Override
    public void onDestroyView() {
        super.onDestroyView();
        if (mClient.isConnected()) {
            mClient.disconnect();
        }
    }

    private void call() {
        AsyncTask.execute(this);
    }

    private GoogleApiClient initClient() {
        GoogleApiClient.ConnectionCallbacks callbacks = new GoogleApiClient.ConnectionCallbacks() {
            @Override
            public void onConnected(Bundle bundle) {
                Log.d(TAG, "CallFragment#onConnected");
            }

            @Override
            public void onConnectionSuspended(int i) {
                Log.d(TAG, "CallFragment#onConnectionSuspended");
            }
        };
        GoogleApiClient.OnConnectionFailedListener listener = new GoogleApiClient.OnConnectionFailedListener() {
            @Override
            public void onConnectionFailed(ConnectionResult connectionResult) {
                Log.d(TAG, "CallFragment#onConnectionFailed");
            }
        };
        GoogleApiClient client = new GoogleApiClient.Builder(getActivity())
                .addApi(Wearable.API)
                .addConnectionCallbacks(callbacks)
                .addOnConnectionFailedListener(listener)
                .build();
        return client;
    }

    @Override
    public void run() {
        if (!mClient.isConnected()) {
            mClient.blockingConnect(100, TimeUnit.MILLISECONDS);
        }
        if (!mClient.isConnected()) {
            Log.i(TAG, "Failed to put phone number to phone - Client disconnected from Google Play Services");
            return;
        }
        String number = getPhoneNumber();
        NodeApi.GetConnectedNodesResult nodes = Wearable.NodeApi.getConnectedNodes(mClient).await();
        for (Node node : nodes.getNodes()) {
            MessageApi.SendMessageResult result = Wearable.MessageApi.sendMessage(mClient, node.getId(), "/calltaxi", number.getBytes()).await();
            Log.i(TAG, "Result:" + result.getStatus());
            Log.i(TAG, "Canceled:" + result.getStatus().isCanceled());
            Log.i(TAG, "Success:" + result.getStatus().isSuccess());
            if (result.getStatus().isSuccess()) {
                Log.i(TAG, "Sent: " + number);
            }
        }
    }

    private String getPhoneNumber() {
        SharedPreferences sp = getActivity().getSharedPreferences(MyActivity.PREF_NAME, Context.MODE_PRIVATE);
        return sp.getString(MyActivity.KEY_NUMBER, "(none)");
    }
}
